@@ -32,7 +32,7 @@ no indirect 'fatal';
 no multidimensional;
 use warnings 'once';
 
-our $VERSION = '0.34';
+our $VERSION = '0.35';
 
 use UI::Various::core;
 use UI::Various::Listbox;
@@ -91,15 +91,16 @@ sub _prepare($$$)
 	error('_1_element_must_be_accompanied_by_parent', __PACKAGE__);
 	return 1;
     }
-    my @options =
-	(-scrollbars => 'oe',
-	 ($self->width < $self->top->max_width ? (-width => $self->width) : ()),
-	 -height => $self->height, # height is mandatory, width is not!
-	 ($self->selection == 2 ? (-selectmode => 'extended') :
-	  (			   -selectmode => 'browse')),
-	 -exportselection => 0);
+    my @attributes = ($self->_attributes());
+    push @attributes,
+	-exportselection => 0,
+	-scrollbars => 'oe',
+	-height => $self->height,	# height is mandatory, width is not!
+	($self->width < $self->top->max_width ? (-width => $self->width) : ()),
+	($self->selection == 2 ? (-selectmode => 'extended') :
+	 (			   -selectmode => 'browse'));
     my $tk_listbox =
-	$_->_tk->Scrolled('Listbox', @options)
+	$_->_tk->Scrolled('Listbox', @attributes)
 	->grid(-row => $row, -column => $column);
     $self->_tk($tk_listbox);
     $tk_listbox->insert(0, @{$self->{texts}});
@@ -129,7 +130,7 @@ L<UI::Various::Listbox::add|UI::Various::Listbox/add - add new element>
 
 sub _add($@)
 {
-    my ($self) = shift;
+    my $self = shift;
     defined $self->_tk  and  $self->_tk->insert('end', @_);
 }
 
@@ -164,7 +165,7 @@ elements>
 
 sub _replace($@)
 {
-    my ($self) = shift;
+    my $self = shift;
     if (defined $self->_tk)
     {
 	$self->_tk->delete(0, 'end');
